@@ -3,7 +3,7 @@ import ql2_pb2 as p
 class RqlError(Exception):
     def __init__(self, message, term, frames):
         self.message = message
-        self.frames = [frame.pos if frame.type is p.Frame.POS else frame.opt for frame in frames]
+        self.frames = [frame.pos if frame.type == p.Frame.POS else frame.opt for frame in frames]
         self.query_printer = QueryPrinter(term, self.frames)
 
     def __str__(self):
